Nxpy Maven
==========

You can install the library with pip::

    pip install nxpy-maven

*Nxpy Maven* provides means to drive the *Maven* Java build tool from Python and to manipulate its
configuration.

The library's documentation is available on
`ReadTheDocs <https://nxpy.readthedocs.io/en/latest/maven.html>`_.
